@@ -1,10 +1,10 @@
 """
-MCPStore - 智能体工具服务商店
-提供简单易用的MCP工具管理和调用功能
+MCPStore - Intelligent Agent Tool Service Store
+Provides simple and easy-to-use MCP tool management and invocation functionality
 """
 
-from mcpstore.core.store import MCPStore
 from mcpstore.config.config import LoggingConfig
+from mcpstore.core.store import MCPStore
 
 __version__ = "0.5.0"
 __all__ = ["MCPStore", "LoggingConfig"]
